@@ -657,6 +657,19 @@ def image_gen(
     return Image(**result) if result is not None else None
 
 
+def image_upload(image: Optional[Image]) -> Optional[Image]:
+    """
+    Upload an image
+    """
+    result = call_return(
+        "botCodeImageUpload",
+        {
+            "image": image,
+        },
+    )
+    return Image(**result) if result is not None else None
+
+
 def google_search(query: str) -> List[SearchArticle]:
     """
     Google search
@@ -835,6 +848,7 @@ def file_create(
     thumbnail: Optional[Image] = None,
     lang: Optional[UserLang] = None,
     indexable: Optional[bool] = None,
+    ui: Optional[dict] = None,
 ) -> File:
     """
     Create file
@@ -850,6 +864,7 @@ def file_create(
                 "thumbnail": thumbnail,
                 "lang": lang,
                 "indexable": indexable,
+                "ui": ui,
             },
         )
     )
@@ -860,6 +875,7 @@ def file_update(
     markdown: Optional[str] = None,
     title: Optional[str] = None,
     thumbnail: Optional[Image] = None,
+    ui: Optional[dict] = None,
 ) -> None:
     """
     Update file, only supported on markdown files
@@ -871,6 +887,7 @@ def file_update(
             "title": title,
             "markdown": markdown,
             "thumbnail": thumbnail,
+            "ui": ui,
         },
     )
 
